flylog
======


### 一. 概述

make log fly to mail or other.  
通过邮件等方式通知到对应的人。


目前支持的通知方式有:

* 邮件
* 钉钉企业消息


python2, python3 supported


### 二. 使用

1. 启动server

        run_flylog.py -c config.py

    具体配置参考 examples/demo_config.py

2. 配置logger

    参考 examples/flask_demo.py
